@@ -20,6 +20,7 @@ use crate::event;
 use crate::event::ReadinessExt;
 use crate::net::{NetListener, NetStream, SocketAddr};
 use crate::reactor::{CustomEvented, FdEvented, IoEvented, Reactor, Registration, TimerEvented};
+use crate::resolver;
 use crate::shuffle::shuffle;
 use crate::tls::TlsStream;
 use crate::zmq::{MultipartHeader, ZmqSocket};
@@ -620,6 +621,28 @@ impl<T> AsyncLocalReceiver<T> {
     }
 }
 
+pub struct AsyncResolver<'a> {
+    resolver: &'a resolver::Resolver,
+}
+
+impl<'a> AsyncResolver<'a> {
+    pub fn new(resolver: &'a resolver::Resolver) -> Self {
+        Self { resolver }
+    }
+
+    pub fn resolve(&self, host: &str) -> QueryFuture {
+        let query = match self.resolver.resolve(host) {
+            Ok(q) => Some(q),
+            Err(()) => None,
+        };
+
+        QueryFuture {
+            evented: None,
+            query,
+        }
+    }
+}
+
 pub struct AsyncTcpListener {
     evented: IoEvented<TcpListener>,
 }
@@ -1221,6 +1244,59 @@ impl<T> Drop for LocalRecvFuture<'_, T> {
     }
 }
 
+pub struct QueryFuture {
+    evented: Option<CustomEvented>,
+    query: Option<resolver::Query>,
+}
+
+impl Future for QueryFuture {
+    type Output = Result<resolver::Addrs, io::Error>;
+
+    fn poll(mut self: Pin<&mut Self>, cx: &mut Context) -> Poll<Self::Output> {
+        let f = &mut *self;
+
+        let query = match &f.query {
+            Some(query) => query,
+            None => return Poll::Ready(Err(io::Error::from(io::ErrorKind::OutOfMemory))),
+        };
+
+        let evented = match &f.evented {
+            Some(evented) => evented,
+            None => {
+                let evented = CustomEvented::new(
+                    query.get_read_registration(),
+                    mio::Interest::READABLE,
+                    &get_reactor(),
+                )
+                .unwrap();
+
+                evented.registration().set_ready(true);
+
+                f.evented = Some(evented);
+
+                f.evented.as_ref().unwrap()
+            }
+        };
+
+        evented
+            .registration()
+            .set_waker(cx.waker(), mio::Interest::READABLE);
+
+        if !evented.registration().is_ready() {
+            return Poll::Pending;
+        }
+
+        match query.process() {
+            Some(ret) => Poll::Ready(ret),
+            None => {
+                evented.registration().set_ready(false);
+
+                Poll::Pending
+            }
+        }
+    }
+}
+
 pub struct AcceptFuture<'a> {
     l: &'a AsyncTcpListener,
 }
@@ -2282,6 +2358,7 @@ mod tests {
     use std::cmp;
     use std::fs;
     use std::mem;
+    use std::net::IpAddr;
     use std::rc::Rc;
     use std::str;
     use std::task::Context;
@@ -2683,6 +2760,30 @@ mod tests {
         executor.run(|_| Ok(())).unwrap();
     }
 
+    #[test]
+    fn test_resolve() {
+        let reactor = Reactor::new(1);
+        let executor = Executor::new(1);
+
+        executor
+            .spawn(async {
+                let resolver = resolver::Resolver::new(1, 1);
+                let resolver = AsyncResolver::new(&resolver);
+
+                let f1 = resolver.resolve("127.0.0.1");
+                let f2 = resolver.resolve("127.0.0.1"); // will error, since queries_max=1
+
+                let addrs = f1.await.unwrap();
+                let e = f2.await.unwrap_err();
+
+                assert_eq!(addrs.as_slice(), &[IpAddr::from([127, 0, 0, 1])]);
+                assert_eq!(e.kind(), io::ErrorKind::OutOfMemory);
+            })
+            .unwrap();
+
+        executor.run(|timeout| reactor.poll(timeout)).unwrap();
+    }
+
     #[test]
     fn test_tcpstream() {
         let reactor = Reactor::new(3); // 3 registrations
